//includes
#include  "msp430g2302.h"
#include  "I2C.h"
#include  "String.h"
#include "LCD.h"



/// InitLCD
/*!
       Inittialisierung des LCD vom Typ EAT123 I2C
       mit folgenden Eigenschaften:
       -voltage generator aktiv weil durch bisher nicht identifizierten Fehler (trotz aktiviertem Inverter) keine Anzeige auf dem Display erscheint.
       -Display wird als 4x12 Zeichen Display initialisiert. Letzte Zeile ist nicht sichtbar

 */
void InitLCD()
{
  
  unsigned char lcd_init[] = {
    0x00,   //nachfolgende sind Controllbytes,
    0x3E,   //Interfacelenght, 4Line, Genertor,
    0x0E,   //Display ON, Cursur OFF, Blink OFF, 
    0x06,
    0x01    //Clear LCD und Reset Cursor
  }; 
   

  __disable_interrupt();
  TI_USI_I2CWrite(LCD_ADDR, sizeof(lcd_init), 0, (unsigned char*) lcd_init);
  __bis_SR_register(LPM0_bits + GIE);
  
}


/// Funktion zum Schreiben einer Zeichenkette auf das LCD.
/*!
       ber die Addition eines Offsets wird ein Zeichensatz ausgewhlt der...
       1. Nicht auf dem Kopf steht
       2. Gro- und Kleinbuchstaben erlaubt
       
       Zur auswahl in welche Zeile des Displays geschrieben werden soll wird ein
       Parameter bergeben der ber die Startposition der zu schreibenden Zeichenkette
       entscheidet


      \param text bergibt die Adresse einer Zeichenfolge die auf dem Display ausgegeben wird
      \param length legt fest, wieviele Zeichen aus der Zeichenkette auf das Display geschrieben werden
      \param line entscheided ber die Startposition des zu schreibenden Textes
                  0x00 1. Zeile, 0x20 2. Zeile, 0x40 3. Zeile
 */

void LCDwrite(unsigned char* text, unsigned char length, unsigned char line)
{
  
  unsigned char newtext[12]={0x40};     //! Erstes Byte im String zur Displaysteuerung (Controlbyte for write Data)
  unsigned char lcd_nav[2] = {0x00,     //Es werden nachfolgend nur Controllbytes gesedet
                              0x00};    //Cursorposition
  
  for(unsigned char i = 0; i<length; i++){    //! Jedem Zeichen des Strings einen Offset von +128 hinzufgen damit die Zeichen auf dem LCD nicht auf dem Kopf stehen
    newtext[i+1]=text[i]+128;
  }
  
  switch(line)
  {
  case 1:
    lcd_nav[1] = 0x80; //Startposition fr Cursor in 1. Zeile
    break;
  case 2:
    lcd_nav[1] = 0xA0; //Startposition fr Cursor in 2. Zeile
    break;
  case 3:
    lcd_nav[1] = 0xC0; //Startposition fr Cursor in 2. Zeile
    break;
  default:
    lcd_nav[1] = 0x80; //Startposition fr Cursor in 1. Zeile
    break;
  }
  
     __disable_interrupt();       //! Cursor an gewnschten Zeilenanfang setzen
  TI_USI_I2CWrite(LCD_ADDR, sizeof(lcd_nav), 0, lcd_nav);
  __bis_SR_register(LPM0_bits + GIE);
  
   __disable_interrupt();       //! neugenerierten String an LCD senden
  TI_USI_I2CWrite(LCD_ADDR, sizeof(newtext), 0, (unsigned char*)newtext);
  __bis_SR_register(LPM0_bits + GIE);


}  
  
/// Funktion zum Setzen des LCD-Cursors auf Position 1
/*!
       Mit Aufrufen dieser Funktion wird der Cursor des LCD Displays auf Position 1
       (1. Zeile) gesetzt
 */
void LCDpos1(void)
{
  unsigned char newtext[]={0x02};  
   __disable_interrupt();       //! Kommando fr "LCD Cursor an Pos. 1
   TI_USI_I2CWrite(LCD_ADDR, 1, 0, (unsigned char*)newtext);
  __bis_SR_register(LPM0_bits + GIE);
}



/// Funktion zum Schreiben von Text ab der aktuellen Cursorposition
/*!
       Mit dieser Funktion wird Text an die aktuelle Cursor-Position geschrieben

      \param text bergibt die Adresse einer Zeichenfolge die auf dem Display ausgegeben wird
      \param length legt fest, wieviele Zeichen aus der Zeichenkette auf das Display geschrieben werden
 */
void LCDappend(unsigned char* text, unsigned char length)
{
  unsigned char newtext[12]={0x40};
  
  for(unsigned char i = 0; i<length; i++){    //! Jedem Zeichen des Strings einen Offset von +128 hinzufgen damit die Zeichen auf dem LCD nicht auf dem Kopf stehen
   newtext[i+1]=text[i]+128;
  }
  
     __disable_interrupt();       //! neugenerierten String an LCD senden
  TI_USI_I2CWrite(LCD_ADDR, sizeof(newtext), 0, (unsigned char*)newtext);
  __bis_SR_register(LPM0_bits + GIE);
  
  
}
